#
# spec file for package zinnia
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?sle_version} > 0 && 0%{?sle_version} < 150400
%define with_python 1
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%else
%define with_python 0
%endif

Name:           zinnia
Version:        0.07
Release:        2.14
Summary:        Online hand recognition system with machine learning
License:        BSD-3-Clause
Group:          System/Libraries
URL:            https://taku910.github.io/zinnia
Source0:        https://github.com/silverhikari/zinnia/releases/download/%{version}/zinnia-%{version}.tar.gz
Patch0:         optflags-fixes.diff
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
%if %{with_python}
BuildRequires:  python-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Zinnia is a simple, customizable and portable online hand recognition system based on Support Vector Machines. Zinnia simply receives user pen strokes as a sequence of coordinate data and outputs n-best characters sorted by SVM confidence. To keep portability, Zinnia doesn\'t have any rendering functionality. In addition to recognition, Zinnia provides training module that allows us to create any hand-written recognition systems with low-cost.

%package -n libzinnia0
Summary:        Shared library for zinnia
Group:          System/Libraries

%description -n libzinnia0
This package contains shared libraries used by zinnia.

%package        devel
Summary:        Development files for zinnia
Group:          Development/Libraries/C and C++
Requires:       libzinnia0 = %{version}

%description    devel
The zinnia-devel package contains libraries and header files for
developing applications that use zinnia.

%if %{with_python}
%package -n python-zinnia
Summary:        Python bindings for zinnia
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description -n python-zinnia
This package contains python bindings for zinnia.
%endif

%prep
%setup -q

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%if %{with_python}
cd python
CFLAGS="%{optflags} -I../" LDFLAGS="-L../.libs" \
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%endif

%post -n libzinnia0 -p /sbin/ldconfig
%postun -n libzinnia0 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc README AUTHORS
%doc doc
%{_bindir}/zinnia
%{_bindir}/zinnia_learn
%{_bindir}/zinnia_convert

%files -n libzinnia0
%license COPYING
%{_libdir}/libzinnia.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/zinnia.h
%{_includedir}/zinnia
%{_libdir}/libzinnia.so
%{_libdir}/pkgconfig/zinnia.pc

%if %{with_python}
%files -n python-zinnia
%defattr (-,root,root)
%{python_sitearch}/*
%endif

%changelog
* Mon Jan  3 2022 Cliff Zhao <qzhao@suse.com>
- Update zinnia.spec: Disable python module building to avoid
  failure in SUSE:SLE-15-SP4:GA (bsc#1193777).
* Fri Dec 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.07
  * Minor bug fixes
- Use source from fork, as source vanished from offical site
- Drop obsoleted patches:
  zinnia-automake-1.13.patch
  zinnia-gcc6.patch
* Fri Jan 10 2020 tiwai@suse.de
- Disable the build with python for Tumbleweed, as python 2 support
  is dropped
* Fri Jun 17 2016 i@marguerite.su
- fix boo#985148: GCC6: zinnia fails to build
- add patch: zinnia-gcc6.patch
  * fix no matching function for call to 'make_pair' error
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Wed Jan  9 2013 jengelh@inai.de
- Parallel build with %%_smp_mflags
- Set license field: "BSD-3-Clause" (from "New BSD")
- Use more robust make install call
* Tue Jun  5 2012 i@marguerite.su
- fix sles and factory builds.
* Tue Aug  9 2011 tiwai@suse.de
- Split libzinnia0 subpackage for shared libraries
- Add python-zinnia subpackage for Python binding
- Include detailed documents in the package
- Clean up spec file
* Fri Jul  1 2011 ftake@geeko.jp
- Initial import
  * upstream version: 0.06
